import micromatch from 'micromatch';

/**
 * Creates a file pattern matcher function
 * @param patterns -Glob patterns to match files
 * @returns A function that returns true if the file matches the patterns
 */
declare function createPatternMatcher(patterns?: string | string[]): (fileName: string) => boolean;
/**
 * Checks if a file name matches a pattern
 *
 * @param fileName -The file name to check
 * @param pattern -The pattern to match
 * @param options -The options to pass to micromatch
 * @returns True if the file name matches the pattern
 */
declare function isMatch(fileName: string, pattern: string | readonly string[], options?: micromatch.Options): boolean;
declare function waitForFile(filePath: string, timeout?: number): Promise<void>;
declare function normalizePath(p: string, shouldResolve?: boolean): string;
declare function normalizeAndResolvePath(p: string): string;
declare const np: typeof normalizePath;
declare function isSamePath(path1: string, path2: string): boolean;

export { createPatternMatcher, isMatch, isSamePath, normalizeAndResolvePath, normalizePath, np, waitForFile };
